==> jc-1.4.0.tar.gz: soot/baf/internal/AbstractBranchInst.h <==
// public abstract class soot.baf.internal.AbstractBranchInst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class cabcce676e3c10e6 soot_baf_internal_AbstractBranchInst
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInst

#include "soot/baf/internal/AbstractInst.h"

#ifndef _JC_soot_baf_internal_AbstractBranchInst_H_
#define _JC_soot_baf_internal_AbstractBranchInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_Unit$object;
struct _jc_soot_UnitBox$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_AbstractBranchInst$sub_refs	_jc_soot_baf_internal_AbstractBranchInst$sub_refs;
typedef struct _jc_soot_baf_internal_AbstractBranchInst$sub_nonrefs	_jc_soot_baf_internal_AbstractBranchInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_AbstractBranchInst$refs	_jc_soot_baf_internal_AbstractBranchInst$refs;
typedef struct _jc_soot_baf_internal_AbstractBranchInst$nonrefs	_jc_soot_baf_internal_AbstractBranchInst$nonrefs;
typedef struct _jc_soot_baf_internal_AbstractBranchInst$object	_jc_soot_baf_internal_AbstractBranchInst$object;

typedef const struct _jc_soot_baf_internal_AbstractBranchInst$vmethods	_jc_soot_baf_internal_AbstractBranchInst$vmethods;
typedef const struct _jc_soot_baf_internal_AbstractBranchInst$vtable	_jc_soot_baf_internal_AbstractBranchInst$vtable;
typedef const struct _jc_soot_baf_internal_AbstractBranchInst$vtype	_jc_soot_baf_internal_AbstractBranchInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_AbstractBranchInst$method$_init$d8711983b77e234f(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_baf_internal_AbstractBranchInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *, struct _jc_object *);
extern jboolean _jc_soot_baf_internal_AbstractBranchInst$method$branches$b1fa209d4c0e0b15(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_AbstractBranchInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *);
extern struct _jc_object *_jc_soot_baf_internal_AbstractBranchInst$method$getTarget$e784b71a3f6b94dd(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *);
extern struct _jc_object *_jc_soot_baf_internal_AbstractBranchInst$method$getTargetBox$30af61fec27c18a3(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *);
extern struct _jc_object *_jc_soot_baf_internal_AbstractBranchInst$method$getUnitBoxes$63a3cb25489f231d(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *);
extern void _jc_soot_baf_internal_AbstractBranchInst$method$setTarget$f351cf06aaa7375f(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_AbstractBranchInst$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *);
extern void _jc_soot_baf_internal_AbstractBranchInst$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$branches$b1fa209d4c0e0b15;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$getTarget$e784b71a3f6b94dd;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$getTargetBox$30af61fec27c18a3;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$getUnitBoxes$63a3cb25489f231d;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$setTarget$f351cf06aaa7375f;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_baf_internal_AbstractBranchInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *, struct _jc_object *);
	jboolean	(*branches$b1fa209d4c0e0b15)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *);
	struct _jc_object	*(*getTarget$e784b71a3f6b94dd)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *);
	struct _jc_object	*(*getTargetBox$30af61fec27c18a3)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *);
	struct _jc_object	*(*getUnitBoxes$63a3cb25489f231d)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *);
	void	(*setTarget$f351cf06aaa7375f)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_baf_internal_AbstractBranchInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractBranchInst$vmethods	soot_baf_internal_AbstractBranchInst;
};

// Vtype
struct _jc_soot_baf_internal_AbstractBranchInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_AbstractBranchInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractBranchInst$sub_refs {
	struct _jc_object	*targetBox;
	struct _jc_object	*targetBoxes;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_AbstractBranchInst$refs {
    _jc_soot_baf_internal_AbstractBranchInst$sub_refs	soot_baf_internal_AbstractBranchInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractBranchInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_AbstractBranchInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractBranchInst$sub_nonrefs	soot_baf_internal_AbstractBranchInst;
};

// Object instance structure
struct _jc_soot_baf_internal_AbstractBranchInst$object {
	_jc_soot_baf_internal_AbstractBranchInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_AbstractBranchInst$vtype	*vtype;
	_jc_soot_baf_internal_AbstractBranchInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_AbstractBranchInst$vtype _jc_soot_baf_internal_AbstractBranchInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_AbstractBranchInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_AbstractBranchInst$class_object;

#endif	/* _JC_soot_baf_internal_AbstractBranchInst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/AbstractBranchInst.h <==
// public abstract class soot.baf.internal.AbstractBranchInst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class cabcce676e3c10e6 soot_baf_internal_AbstractBranchInst
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInst

#include "soot/baf/internal/AbstractInst.h"

#ifndef _JC_soot_baf_internal_AbstractBranchInst_H_
#define _JC_soot_baf_internal_AbstractBranchInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_Unit$object;
struct _jc_soot_UnitBox$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_AbstractBranchInst$sub_refs	_jc_soot_baf_internal_AbstractBranchInst$sub_refs;
typedef struct _jc_soot_baf_internal_AbstractBranchInst$sub_nonrefs	_jc_soot_baf_internal_AbstractBranchInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_AbstractBranchInst$refs	_jc_soot_baf_internal_AbstractBranchInst$refs;
typedef struct _jc_soot_baf_internal_AbstractBranchInst$nonrefs	_jc_soot_baf_internal_AbstractBranchInst$nonrefs;
typedef struct _jc_soot_baf_internal_AbstractBranchInst$object	_jc_soot_baf_internal_AbstractBranchInst$object;

typedef const struct _jc_soot_baf_internal_AbstractBranchInst$vmethods	_jc_soot_baf_internal_AbstractBranchInst$vmethods;
typedef const struct _jc_soot_baf_internal_AbstractBranchInst$vtable	_jc_soot_baf_internal_AbstractBranchInst$vtable;
typedef const struct _jc_soot_baf_internal_AbstractBranchInst$vtype	_jc_soot_baf_internal_AbstractBranchInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_AbstractBranchInst$method$_init$d8711983b77e234f(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_baf_internal_AbstractBranchInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_baf_internal_AbstractBranchInst$method$branches$b1fa209d4c0e0b15(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_AbstractBranchInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_baf_internal_AbstractBranchInst$method$getTarget$e784b71a3f6b94dd(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_baf_internal_AbstractBranchInst$method$getTargetBox$30af61fec27c18a3(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_baf_internal_AbstractBranchInst$method$getUnitBoxes$63a3cb25489f231d(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_internal_AbstractBranchInst$method$setTarget$f351cf06aaa7375f(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_AbstractBranchInst$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_internal_AbstractBranchInst$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$branches$b1fa209d4c0e0b15;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$getTarget$e784b71a3f6b94dd;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$getTargetBox$30af61fec27c18a3;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$getUnitBoxes$63a3cb25489f231d;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$setTarget$f351cf06aaa7375f;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_baf_internal_AbstractBranchInst$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_baf_internal_AbstractBranchInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*branches$b1fa209d4c0e0b15)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getTarget$e784b71a3f6b94dd)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getTargetBox$30af61fec27c18a3)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getUnitBoxes$63a3cb25489f231d)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *) _JC_JCNI_ATTR;
	void	(*setTarget$f351cf06aaa7375f)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_baf_internal_AbstractBranchInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_AbstractBranchInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractBranchInst$vmethods	soot_baf_internal_AbstractBranchInst;
};

// Vtype
struct _jc_soot_baf_internal_AbstractBranchInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_AbstractBranchInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractBranchInst$sub_refs {
	struct _jc_object	*targetBox;
	struct _jc_object	*targetBoxes;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_AbstractBranchInst$refs {
    _jc_soot_baf_internal_AbstractBranchInst$sub_refs	soot_baf_internal_AbstractBranchInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractBranchInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_AbstractBranchInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractBranchInst$sub_nonrefs	soot_baf_internal_AbstractBranchInst;
};

// Object instance structure
struct _jc_soot_baf_internal_AbstractBranchInst$object {
	_jc_soot_baf_internal_AbstractBranchInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_AbstractBranchInst$vtype	*vtype;
	_jc_soot_baf_internal_AbstractBranchInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_AbstractBranchInst$vtype _jc_soot_baf_internal_AbstractBranchInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_AbstractBranchInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_AbstractBranchInst$class_object;

#endif	/* _JC_soot_baf_internal_AbstractBranchInst_H_ */
